@@ -453,8 +453,8 @@ class TestLDAPObject(unittest.TestCase):
 
         self.ldapobj.modify_s(manager[0], mod_list)
 
-        self.assertNotIn('objectClass',
-                         self.ldapobj.directory[manager[0]].keys())
+        self.assertEqual(self.ldapobj.directory[manager[0]]['objectClass'],
+                         [])
 
     def test_modify_s_invalid_dn(self):
         mod_list = [(ldap.MOD_DELETE, 'objectClass', None)]
@@ -557,6 +557,11 @@ class TestLDAPObject(unittest.TestCase):
 
         self.assertEqual(self.ldapobj.bound_as, None)
 
+    def test_whoami_s(self):
+        self.ldapobj.simple_bind_s(alice[0], 'alicepw')
+
+        self.assertEqual(self.ldapobj.whoami_s(), 'dn:cn=alice,ou=example,o=test')
+
 
 def initialize(*args, **kwargs):
     """ Dummy patch target for the tests below. """
